# -*- coding: utf-8 -*-
import irc3
import requests

from docopt import Dict as DocOptDict
from irc3.plugins.command import command
from irc3.utils import IrcString

from . import Plugin


@irc3.plugin
class Urban(Plugin):
    requires = ['irc3.plugins.command']

    URL = 'https://api.urbandictionary.com/v0/define'

    @command
    def ud(self, mask: IrcString, target: IrcString, args: DocOptDict):
        """Searches for a term on YouTube and returns first result.

        %%ud <term>...
        """
        term = ' '.join(args.get('<term>')).lower().strip().split()

        if term[-1].isdigit():
            idx = int(term[-1]) - 1
            term = ' '.join(term[:-1])
        else:
            idx = 0

        data = requests.get(self.URL, params=dict(term=term)).json()
        if data['result_type'] == 'no_results':
            return 'Term not found'

        res = data['list'][idx]
        return '[{idx}/{len}] \x02{word}\x02: {definition} - {example}'.format(
            idx=idx + 1,
            len=len(data['list']),
            word=res['word'],
            definition=res['definition'].replace('\r\n', ' '),
            example=res['example'].replace('\r\n', ' '),
        )
